@@ -4,6 +4,6 @@
   packageStartupMessage("################################################################################\n")
   packageStartupMessage("Easy Microarray Analysis\n")
   packageStartupMessage("EMA stable version\n")
-  packageStartupMessage("Current release : v1.4.3 - july 2013\n")
+  packageStartupMessage("Current release : v1.4.4 - march 2014\n")
   packageStartupMessage("################################################################################\n")    
 }
